# remirepo spec file for php-pecl-scoutapm
#
# Copyright (c) 2019-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package       php-pecl-scoutapm
%endif

%bcond_without    tests

%global pecl_name scoutapm
%global with_zts  0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name  15-%{pecl_name}.ini

Summary:        Native Extension Component for ScoutAPM's PHP Agent
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        1.8.2
Release:        2%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz
License:        PHP
URL:            https://pecl.php.net/package/%{pecl_name}

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.1
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-json
# Only for tests
BuildRequires:  %{?scl_prefix}php-curl
BuildRequires:  %{?scl_prefix}php-pdo
BuildRequires:  %{?scl_prefix}php-pdo_sqlite
BuildRequires:  libcurl-devel
BuildRequires:  /bin/ps

Requires:       %{?scl_prefix}php-json%{?_isa}
Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
ScoutAPM's extension for PHP provides additional capabilities to application
monitoring over just using the base PHP userland library.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{pecl_name}-%{version} NTS

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

pushd NTS
: Check version
extver=$(sed -n '/#define PHP_SCOUTAPM_VERSION /{s/.* "//;s/".*$//;p}' zend_scoutapm.h)
if test "x${extver}" != "x%{version}%{?prever}"; then
   : Error: Upstream version is ${extver}, expecting %{version}%{?prever}.
   exit 1
fi
popd

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
zend_extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --enable-scoutapm \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-scoutapm \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd NTS
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done
%{!?_licensedir:install -Dpm 644 LICENSE %{buildroot}%{pecl_docdir}/%{pecl_name}/LICENSE}


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
DEPS="-n"
[ -f %{php_extdir}/json.so ]  && DEPS="$DEPS -d extension=json.so"

# Minimal load test for NTS extension
%{__php} $DEPS \
    --define zend_extension=$PWD/NTS/modules/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_zts}
# Minimal load test for ZTS extension
%{__ztsphp} $DEPS \
    --define zend_extension=$PWD/ZTS/modules/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif

DEPS="$DEPS -d extension=curl.so -d extension=pdo.so -d extension=pdo_sqlite.so"

%if %{with tests}
: Upstream test suite for NTS extension
cd NTS
rm tests/*elastic*.phpt

TEST_PHP_ARGS="$DEPS -d zend_extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -P -q --show-diff
%endif


%files
%{?_licensedir:%license NTS/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Sep 15 2022 Remi Collet <remi@remirepo.net> - 1.8.2-2
- PHP build

* Mon Aug 29 2022 Remi Collet <remi@remirepo.net> - 1.8.2-1
- update to 1.8.2

* Wed Jul 27 2022 Remi Collet <remi@remirepo.net> - 1.8.1-1
- update to 1.8.1 (no change)

* Wed Jun 29 2022 Remi Collet <remi@remirepo.net> - 1.8.0-1
- update to 1.8.0

* Mon Apr 25 2022 Remi Collet <remi@remirepo.net> - 1.7.0-1
- update to 1.7.0

* Mon Jan 10 2022 Remi Collet <remi@remirepo.net> - 1.6.0-1
- update to 1.6.0

* Sat Dec 25 2021 Remi Collet <remi@remirepo.net> - 1.5.1-1
- update to 1.5.1
- drop patch merged upstream

* Thu Dec 23 2021 Remi Collet <remi@remirepo.net> - 1.5.0-1
- update to 1.5.0
- add dependency on json extension
- add patch to allow build with shared json from
  https://github.com/scoutapp/scout-apm-php-ext/pull/99

* Fri Nov  5 2021 Remi Collet <remi@remirepo.net> - 1.4.3-2
- EL-9 build

* Fri Oct 29 2021 Remi Collet <remi@remirepo.net> - 1.4.3-1
- update to 1.4.3

* Tue Jun 29 2021 Remi Collet <remi@remirepo.net> - 1.4.2-1
- update to 1.4.2

* Tue Jun 29 2021 Remi Collet <remi@remirepo.net> - 1.4.1-1
- update to 1.4.1

* Thu Jun 17 2021 Remi Collet <remi@remirepo.net> - 1.4.0-1
- update to 1.4.0

* Thu Jun 17 2021 Remi Collet <remi@remirepo.net> - 1.3.0-1
- update to 1.3.0

* Fri Mar 19 2021 Remi Collet <remi@remirepo.net> - 1.2.2-1
- update to 1.2.2

* Sat Feb  6 2021 Remi Collet <remi@remirepo.net> - 1.2.1-1
- update to 1.2.1
- drop patch merged upstream

* Fri Feb  5 2021 Remi Collet <remi@remirepo.net> - 1.2.0-2
- add patch for PHP 8 / ZTS from
  https://github.com/scoutapp/scout-apm-php-ext/pull/69

* Thu Feb  4 2021 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0
- open https://github.com/scoutapp/scout-apm-php-ext/issues/67
  test failure with PHP 8.0 and TS build

* Wed Feb 19 2020 Remi Collet <remi@remirepo.net> - 1.1.1-1
- update to 1.1.1 (no change)
- drop patch merged upstream

* Wed Feb 19 2020 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0
- add patch for libcurl detection from
  https://github.com/scoutapp/scout-apm-php-ext/pull/62

* Tue Nov 26 2019 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Wed Nov  6 2019 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Wed Nov  6 2019 Remi Collet <remi@remirepo.net> - 1.0.0-2
- test build with upstream patch for
  https://github.com/scoutapp/scout-apm-php-ext/issues/47

* Mon Nov  4 2019 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0

* Fri Sep 27 2019 Remi Collet <remi@remirepo.net> - 0.0.4-1
- update to 0.0.4
- drop patch merged upstream

* Tue Sep 17 2019 Remi Collet <remi@remirepo.net> - 0.0.3-1
- update to 0.0.3
- add build patch from
  https://github.com/scoutapp/scout-apm-php-ext/pull/32
  https://github.com/scoutapp/scout-apm-php-ext/pull/34

* Tue Sep 17 2019 Remi Collet <remi@remirepo.net> - 0.0.2-1
- initial package
